@@ -9,14 +9,9 @@
 #ifndef KIRIGAMIPLUGIN_H
 #define KIRIGAMIPLUGIN_H
 
-#include <QUrl>
-
 #include <QQmlEngine>
 #include <QQmlExtensionPlugin>
-
-#ifdef KIRIGAMI_BUILD_TYPE_STATIC
-#include <QDebug>
-#endif
+#include <QUrl>
 
 class KirigamiPlugin : public QQmlExtensionPlugin
 {
@@ -29,22 +24,8 @@ public:
     void initializeEngine(QQmlEngine *engine, const char *uri) override;
 
 #ifdef KIRIGAMI_BUILD_TYPE_STATIC
-    static KirigamiPlugin &getInstance()
-    {
-        static KirigamiPlugin instance;
-        return instance;
-    }
-
-    static void registerTypes(QQmlEngine *engine = nullptr)
-    {
-        Q_INIT_RESOURCE(shaders);
-        if (engine) {
-            engine->addImportPath(QLatin1String(":/"));
-        } else {
-            qWarning() << "Registering Kirigami on a null QQmlEngine instance - you likely want to pass a valid engine, or you will want to manually add the "
-                          "qrc root path :/ to your import paths list so the engine is able to load the plugin";
-        }
-    }
+    static KirigamiPlugin &getInstance();
+    static void registerTypes(QQmlEngine *engine = nullptr);
 #endif
 
 Q_SIGNALS:
